# Personal Git Hooks
This directory contains some scripts designed for use as [git hooks](https://git-scm.com/docs/githooks). They generally have a pretty simple command line interface (see docstrings for details) so usage should be self-explanatory.

You can install the entire hook package with `pip install metovhooks`.
